"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
exports.plugin = async (schema, documents) => {
    const mappedDocuments = documents.reduce((prev, documentRecord) => {
        const fileName = path_1.basename(documentRecord.filePath);
        if (!prev[fileName]) {
            prev[fileName] = [];
        }
        prev[fileName].push(...documentRecord.content.definitions.filter(document => document.kind === 'OperationDefinition' || document.kind === 'FragmentDefinition'));
        return prev;
    }, {});
    return Object.keys(mappedDocuments)
        .filter(fileName => mappedDocuments[fileName].length > 0)
        .map(fileName => {
        const operations = mappedDocuments[fileName];
        return `
declare module '*/${fileName}' {
  import { DocumentNode } from 'graphql';
  const defaultDocument: DocumentNode;
  ${operations
            .filter(d => d.name && d.name.value)
            .map(d => `export const ${d.name.value}: DocumentNode;`)
            .join('\n')}

  export default defaultDocument;
}
    `;
    })
        .join('\n');
};
exports.validate = async (schema, documents, config, outputFile) => {
    if (!outputFile.endsWith('.d.ts')) {
        throw new Error(`Plugin "typescript-graphql-files-modules" requires extension to be ".d.ts"!`);
    }
};
//# sourceMappingURL=index.js.map